@@ -4,7 +4,7 @@ use Mojo::Base -base;
 use Role::Tiny;
 use Carp qw/croak/;
 
-our $VERSION = '1.003001'; # VERSION
+our $VERSION = '1.004001'; # VERSION
 
 sub click_ok {
     my ( $self, $selector_or_dom, $extra_params ) = @_;
@@ -16,12 +16,14 @@ sub click_ok {
             || croak 'Test::Mojo::Role::SubmitForm::click_ok()'
                 . " Did not find element matching selector $selector_or_dom";
     unless ( $el->tag eq 'form' ) {
-        if ( $el->{type} eq 'image' ) {
-            $extra_params->{ $el->{name} . '.x' } = 1;
-            $extra_params->{ $el->{name} . '.y' } = 1;
-        }
-        else {
-            $extra_params->{ $el->{name} } = $el->val;
+        if (length $el->{name}) {
+            if ( ($el->{type}//'') eq 'image' ) {
+                $extra_params->{ $el->{name} . '.x' } = 1;
+                $extra_params->{ $el->{name} . '.y' } = 1;
+            }
+            else {
+                $extra_params->{ $el->{name} } = $el->val;
+            }
         }
 
         $el = $el->ancestors('form')->first;
@@ -39,6 +41,9 @@ sub click_ok {
         $self->_get_controls($el),
         %$extra_params,
     );
+    for (keys %form) {
+        delete $form{$_} unless defined $form{$_}
+    }
 
     if ( $ENV{MOJO_SUBMITFORM_DEBUG} ) {
         warn "\n########## SUBMITTING FORM ##########\n";
@@ -149,6 +154,7 @@ You have all the methods provided by L<Test::Mojo>, plus these:
     $t->click_ok('#button', {
         input1        => '42',
         select1       => [ 1..3 ],
+        remove_me     => undef,
         other_select  => sub { my $r = shift; [ @$r, 42 ] },
         another_input => sub { shift . 'offix'}
     })
@@ -163,7 +169,7 @@ Specifying a second parameter allows you to override the form control values:
 the keys are C<name="">s of controls to override and values can be either
 plain scalars (use arrayrefs for multiple values) or subrefs. Subrefs
 will be evaluated and their first C<@_> element will be the current value
-of the form control.
+of the form control. Use C<undef> as value to remove form's parameter.
 
 =head1 DEBUGGING / ENV VARS
 
